@@ -15,11 +15,11 @@ def decrypt_file(encrypted_file: str, private_key_path: str):
     """The decrypt_file function takes in an encrypted file and a private key,
     then decrypts the file using the private key.
 
-    :param encrypted_file: str: Used to Pass the file name of the
-        encrypted file to be decrypted.
-    :param private_key: str: Used to Read the private key file and
-        decrypt the encrypted message.
-    :return: The original message.  :doc-author: Julian M. Kleber
+    :param encrypted_file:str: Used to Pass the file name of the encrypted file to be decrypted.
+    :param private_key:str: Used to Read the private key file and decrypt the encrypted message.
+    :return: The original message.
+
+    :doc-author: Julian M. Kleber
     """
 
     with open(encrypted_file, "rb") as ecf:
@@ -53,20 +53,14 @@ def encrypt_file(
     its encrypted version. Otherwise it will create a new encrypted version of
     that file.
 
-    :param file_name:str: Used to Specify the name of the file to be
-    encrypted. :param public_key:str: Used to Specify the name of the
-    public key file. :param in_place:bool=False: Used to Determine
-    whether the file should be overwritten or not. :param save_
-    file:Optional[str]=None:
-    :param file_name: str: Used to Specify the name of the file to be
-        encrypted.
-    :param public_key: str: Used to Specify the name of the public key
-        file.
-    :param in_place: bool=False: Used to Determine whether the file
-        should be overwritten or not.
-    :param save_file: Optional[str]=None: Used to Allow the user to
-        specify a file name for saving the encrypted file.
-    :return: None.  :doc-author: Julian M. Kleber
+    :param file_name:str: Used to Specify the name of the file to be encrypted.
+    :param public_key:str: Used to Specify the name of the public key file.
+    :param in_place:bool=False: Used to Determine whether the file should be overwritten or not.
+    :param save_file:Optional[str]=None: Used to Allow the user to specify a file name for saving
+    the encrypted file.
+    :return: None.
+
+    :doc-author: Julian M. Kleber
     """
 
     with open(public_key_file, "rb") as key_file:
@@ -100,12 +94,12 @@ def generate_asymmetric_keys(
     key pair. The keys are generated using the RSA algorithm with a specified
     bit size. The keys are then written to files in PEM format.
 
-    :param key_size: int: Used to specify the size of the key that will
-        be generated.
-    :param private_key_name: str: Used to Name the private key file.
-    :param public_key_name: str: Used to specify the name of the public
-        key file.
-    :return: The private and public keys.  :doc-author: Julian M. Kleber
+    :param key_size:int: Used to specify the size of the key that will be generated.
+    :param private_key_name:str: Used to Name the private key file.
+    :param public_key_name:str: Used to specify the name of the public key file.
+    :return: The private and public keys.
+
+    :doc-author: Julian M. Kleber
     """
 
     private_key_name = prepare_file_name_saving(private_key_name)
