@@ -23,19 +23,6 @@ from .checks import check_make_file_name_suffix, check_make_dir
 LOGGER = logging.getLogger(__name__)
 
 
-def read_file(file_name: str, encoding="ISO-8859-1") -> str:
-    with open(file_name, "r", encoding=encoding) as f:
-        content = f.read()
-    return content
-
-
-def write_txt_file(content: str, file_name: str, encoding: str = "ISO-8859-1"):
-    file_name = prepare_file_name_saving(file_name=file_name)
-    with open(file_name, "w", encoding=encoding) as txt_file:
-        txt_file.write(content)
-    logging.info("Wrote txt file to " + file_name)
-
-
 def prepare_file_name_saving(
     file_name: str,
     prefix: Optional[str | Type[None]] = None,
@@ -45,12 +32,11 @@ def prepare_file_name_saving(
     input. It checks to see if the directory exists, and makes it if not. Then
     it returns the full path of the file.
 
-    :param prefix: str: Used to specify the folder where the file will
-        be saved.
-    :param file_name: str: Used to specify the name of the file to be
-        saved.
-    :return: The full path of the file name. :doc-author: Julian M.
-        Kleber
+    :param prefix:str: Used to specify the folder where the file will be saved.
+    :param file_name:str: Used to specify the name of the file to be saved.
+    :return: The full path of the file name.
+
+    :doc-author: Julian M. Kleber
     """
     if suffix == "" or suffix is None:
         file_name, suffix = os.path.splitext(file_name)
@@ -70,12 +56,12 @@ def insert_string_in_file_name(file_name: str, insertion: str, suffix: str) -> s
     file_name, or if there is no extension, it will be placed at the end of the
     file_name with an suffix specified by you.
 
-    :param file_name: str: Used to Specify the file name that you want
-        to insert a string into.
-    :param insertion: str: Used to Specify the string that will be
-        inserted into the file name.
-    :param suffix: str: Used to Specify the file suffix.
-    :return: A string.  :doc-author: Julian M. Kleber
+    :param file_name:str: Used to Specify the file name that you want to insert a string into.
+    :param insertion:str: Used to Specify the string that will be inserted into the file name.
+    :param suffix:str: Used to Specify the file suffix.
+    :return: A string.
+
+    :doc-author: Julian M. Kleber
     """
 
     root, ext = os.path.splitext(file_name)
@@ -126,10 +112,10 @@ def load_json_from_file(file_name: str) -> Dict[Any, Any]:
     """The load_json_from_file function takes a file name as input and returns
     the contents of that file in JSON format.
 
-    :param file_name: str: Used to Specify the file name of the json
-        file to be loaded.
-    :return: A dictionary of the data in the file. :doc-author: Julian
-        M. Kleber
+    :param file_name:str: Used to Specify the file name of the json file to be loaded.
+    :return: A dictionary of the data in the file.
+
+    :doc-author: Julian M. Kleber
     """
 
     with open(file_name, "r", encoding="utf-8") as json_file:
@@ -141,9 +127,10 @@ def save_json_to_file(dictionary: Dict[Any, Any], file_name: str) -> None:
     """The save_json function saves a dictionary to a json file.
 
     :param dictionary: Used to store the data that will be saved.
-    :param file_name: str=None: Used to specify a file name.
+    :param file_name:str=None: Used to specify a file name.
     :return: A string with the name of the file that was just created.
-        :doc-author: Julian M. Kleber
+
+    :doc-author: Julian M. Kleber
     """
 
     def convert(np_data: Union[npt.NDArray[Any], Type[np.generic]]) -> Any:
@@ -151,11 +138,13 @@ def save_json_to_file(dictionary: Dict[Any, Any], file_name: str) -> None:
         of that object. If the input is an array, it will return a list of
         values. If it is not an array, it will return just the value.
 
-        :param o: Union[Type(np.ndarray): Used to Specify the type of
-            object that will be passed to the function. :param
-            Type(np.generic)]: Used to Specify the type of object that
-            is being passed into the function.
-        :return: The value of the input object.  :doc-author: Trelent
+        :param o:Union[Type(np.ndarray): Used to Specify the type of object that will be passed to
+        the function.
+        :param Type(np.generic)]: Used to Specify the type of object that is being passed into
+        the function.
+        :return: The value of the input object.
+
+        :doc-author: Trelent
         """
 
         val = None
@@ -179,11 +168,12 @@ def make_date_file_name(prefix: str = "", file_name: str = "", suffix: str = "")
     arguments are provided, then make_date_file_name will use default values
     for all three arguments.
 
-    :param prefix: str="": Used to ddd a prefix to the file name.
-    :param file_name: str="": Used to specify the name of the file.
-    :param suffix: str=".out": Used to specify the file extension.
-    :return: A string that is the combination of prefix, file_name and
-        suffix. :doc-author: Julian M. Kleber
+    :param prefix:str="": Used to ddd a prefix to the file name.
+    :param file_name:str="": Used to specify the name of the file.
+    :param suffix:str=".out": Used to specify the file extension.
+    :return: A string that is the combination of prefix, file_name and suffix.
+
+    :doc-author: Julian M. Kleber
     """
     time_str = time.strftime("%Y%m%d-%H%M%S" + prefix + file_name + suffix)
     return time_str
@@ -216,9 +206,10 @@ def search_subdirs(dir_name: str) -> Tuple[List[str], List[str]]:
     directory, including those in subdirectories. The second list contains all
     the subdirectories.
 
-    :param dir_name: str: Used to Specify the directory that we want to
-        search.
-    :return: A tuple of two lists.  :doc-author: Julian M. Kleber
+    :param dir_name:str: Used to Specify the directory that we want to search.
+    :return: A tuple of two lists.
+
+    :doc-author: Julian M. Kleber
     """
     if not dir_name.endswith("/"):
         dir_name += "/"
@@ -239,11 +230,11 @@ def write_tar(target_dir: str, file_name: str) -> None:
     arguments. It then creates a tar file with the given output name, and adds
     all files in the target directory to it.
 
-    :param target_dir: str: Used to Specify the directory that you want
-        to compress.
-    :param out_name: str: Used to Specify the name of the tar file that
-        will be created.
-    :return: None.  :doc-author: Julian M. Kleber
+    :param target_dir:str: Used to Specify the directory that you want to compress.
+    :param out_name:str: Used to Specify the name of the tar file that will be created.
+    :return: None.
+
+    :doc-author: Julian M. Kleber
     """
 
     with tarfile.open(file_name, "w") as tar:
@@ -260,11 +251,11 @@ def copy_dir(old_dir: str, new_dir: str, overwrite=True) -> None:
     copies all files from the old directory to the new directory. If either of
     these directories do not end with a "/", it will be added.
 
-    :param old_dir: str: Used to Specify the directory that you want to
-        copy from.
-    :param new_dir: str: Used to Specify the new directory that you want
-        to copy your files into.
-    :return: None.  :doc-author: Julian M. Kleber
+    :param old_dir:str: Used to Specify the directory that you want to copy from.
+    :param new_dir:str: Used to Specify the new directory that you want to copy your files into.
+    :return: None.
+
+    :doc-author: Julian M. Kleber
     """
 
     check_make_dir(new_dir)
@@ -282,9 +273,10 @@ def convert_str_to_bool(bool_str: str) -> None:
     boolean. The function is used in the main() function to convert the
     override value from a string to a boolean.
 
-    :param bool_str: str: Used to Specify the type of data that will be
-        passed into the function.
-    :return: None.  :doc-author: Julian M. Kleber
+    :param bool_str:str: Used to Specify the type of data that will be passed into the function.
+    :return: None.
+
+    :doc-author: Julian M. Kleber
     """
 
     if bool_str == "True":
@@ -294,15 +286,15 @@ def convert_str_to_bool(bool_str: str) -> None:
     return bool_str
 
 
-def attach_slash(raw_string: str) -> str:
-    """The attach_slash function takes a string as input and returns the same
+def append_slash(raw_string: str) -> str:
+    """The append_slash function takes a string as input and returns the same
     string with a slash appended to it. If the input already ends in a slash,
     then no change is made.
 
-    :param raw_string: str: Used to Specify the type of data that is
-        being passed into the function.
-    :return: A string with a trailing slash. :doc-author: Julian M.
-        Kleber
+    :param raw_string:str: Used to Specify the type of data that is being passed into the function.
+    :return: A string with a trailing slash.
+
+    :doc-author: Julian M. Kleber
     """
 
     if not raw_string.endswith("/"):
